//tabstop=4
//*****************************************************************************/
// Project: Orbasec
//
// File:    Kerberos_Kinit.java
// Date:    March 1998
//
// Description:
//    			Makes native calls to "kinit" in kerberosv5 clients package.
//
// -------------------------------------------------------------------------
// Copyright (C) 1998 Polar Humenn
//                    All rights reserved.
// -------------------------------------------------------------------------
// $Id$
//*****************************************************************************/
package orbasec.krb5;


//----------------------------------------------------------------------/
// Kerberos_Kinit
/**
 * This class is used for authentication using kerberosv5 kinit
 * client program. It bases itself on converting the kinit program
 * main() function to kinit() and running it.
 * 
 * @version $Revision$
 */
// Implementation notes:  
// 
//----------------------------------------------------------------------/
public class Kerberos_Kinit
{
   //------------------------------------------------------------------/
    // initialize static
    /**
     * Loads the library containing the kinit function.
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/
	static gss gss_holder = new gss();

    //------------------------------------------------------------------/
    // kinit
    /**
     * This method is used to obtain kerberos tickets through the
     * native kinit function. The native kinit funciton is
     * a converion of main().
     *
     * @param  argc          The number of arguments passed to kinit  
     * @param  argv 		 Arguments to kinit.
     * @param  password      Password, if needed.   
     *    
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/                 	

	private static void internal_kinit (
		  String arg_configfile,
		  String arg_principal,
		  String arg_password,
		  String arg_cache,
		  String arg_keytab,
		  boolean arg_write_to_keytab,
		  String arg_forwardable,
		  String arg_proxiable,
		  String arg_service_name,
		  String arg_validate,
		  String arg_renew,
		  String arg_lifetime,
          String arg_rlife,
		  String arg_postdate
	){
		gss_string_holder arg_errmsg = new gss_string_holder();
		int ret = kinit(
		  arg_configfile == null ? "" :  arg_configfile,
		  arg_principal == null ? "" :   arg_principal,
		  arg_password == null ? "" : 	 arg_password,
		  arg_cache == null ? "" :  	 arg_cache,
		  arg_keytab == null ? "" : 	 arg_keytab,
		  arg_write_to_keytab,
		  arg_forwardable == null ? "" : arg_forwardable,
		  arg_proxiable == null ? "" :   arg_proxiable,
		  arg_service_name == null ? "" :arg_service_name,
		  arg_validate == null ? "" : 	 arg_validate,
		  arg_renew == null ? "" :  	 arg_renew,
		  arg_lifetime == null ? "" : 	 arg_lifetime,
          arg_rlife == null ? "" :  	 arg_rlife,
		  arg_postdate == null ? "" : 	 arg_postdate,
		  arg_errmsg
		);
		if (ret != 0) {
			throw new org.omg.CORBA.NO_PERMISSION(
						arg_errmsg.buffer(),
						orbasec.corba.MinorNoPermission.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	private static native int kinit (
		  String arg_configfile,
		  String arg_principal,
		  String arg_password,
		  String arg_cache,
		  String arg_keytab,
		  boolean arg_write_to_keytab,
		  String arg_forwardable,
		  String arg_proxiable,
		  String arg_service_name,
		  String arg_validate,
		  String arg_renew,
		  String arg_lifetime,
          String arg_rlife,
		  String arg_postdate,
		  gss_string_holder  arg_errmsg
	);
	
    //------------------------------------------------------------------/
    // getCredentials
    /**
     * This method is used to obtain kerberos ticket granting ticket for
     * a given principal.
     *
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/ 
	public final static boolean
	getCredentials( String conf_file,
	                String keytab_name,
					String cache_name,
					String principal,
					String password,
					boolean write_to_keytab,
					boolean forwardable,
					String lifetime,
					String renewable_life )
	{
		internal_kinit(
			conf_file,
			principal,
			password,
			cache_name,
			keytab_name,
			write_to_keytab,
			forwardable ? "true" : "",
			"", // proxiable
			"", // service name
			"", // validate
			"", // renew
			lifetime,
			renewable_life,
			"" // postdate
		);
		return true;
	}
		
	public final static boolean
	refresh(String conf_file, String ccache)
	{
		internal_kinit(
		              conf_file,
					  "", // principal
					  "", // password
					  ccache,
					  "", // keytab
					  false, // write_to_keytab
					  "", // forwardable
					  "", // proxiable
					  "", // service_name
					  "", // validate
					  "true", // renew
					  "", // lifetime
					  "", // renewable_life
					  ""  // postdate
			);
	   return true;
	}
	
}

