//tabstop=4
//*****************************************************************************/
// Project: Orbasec
//
// File:    AuthData.java
// Date:    August 1998
//
// Description:
//    
//
// -------------------------------------------------------------------------
// Copyright (C) 1998 Polar Humenn
//                    All rights reserved.
// -------------------------------------------------------------------------
// $Id$
//*****************************************************************************/
package orbasec.secrep.gsskrb5;

import java.util.Properties;
import java.io.StringBufferInputStream;
import java.io.ByteArrayOutputStream;
import java.io.PrintWriter;
import java.io.IOException;

import orbasec.util.TextS;
import orbasec.util.TextReadException;


//----------------------------------------------------------------------/
// AuthData
/**
 *  This is a small class to help get data into the Principal authenticator.
 *
 */
// Implementation notes:  
// 
//----------------------------------------------------------------------/
public class AuthData
	extends Properties
{
	public final static String Delegation    = "delegation",
	                           EnableServer  = "enable_server",
	                           ConfigFile    = "config",
	                           Password      = "password",
	                           Keytab        = "keytab",
	                           CacheName     = "cache_name",
	                           Lifetime      = "lifetime",
	                           RenewableLife = "renewable_life",
							   Authenticator = "authenticator";
	                    
	public AuthData()
	{
	}
	
	String password = "";
	
	public AuthData(byte[] bytes)
	{
		load(bytes);
		// Type checking?
		// delegation should be boolean
		// password should be in quotes
		// keytab should be a file name
		// cachename should be a file name
		// lifetime should be a time
		// renewable_life should be a time
		// authenticator should be one of [text,visual]
		
		String p = getProperty(Password);
		if (p == null) {
			setPassword("\"\"");
		} else {
		  if (!p.startsWith("\"") && !p.endsWith("\"") ) {
			throw new org.omg.CORBA.BAD_PARAM("Password for authentication data must be in quotes");
		  }
		  password = p.substring(1,p.length()-1);
		}
		
	}
	
	public Object
	put(Object key, Object obj)
	{
		return super.put(((String)key).toLowerCase(), obj);
	}
	
	public String
	getProperty(String key)
	{
		return super.getProperty(key.toLowerCase());
	}
	
	public void                
	load(byte[] bytes)
	{
		try {
			java.io.InputStream in = 
		                new java.io.ByteArrayInputStream( bytes );
			load(in);
		} catch (IOException ex) {
			throw new org.omg.CORBA.INTERNAL("AuthData: bad load");
		}
	}
	
	public byte[]
	toByteArray()
	{
		ByteArrayOutputStream p = new ByteArrayOutputStream();
		
		save(p,"");
		
		return p.toByteArray();
	}
	
	public boolean getDelegation()
	{
		String s = getProperty(Delegation, "false");
		return new Boolean(s).booleanValue();
	}
	
	public boolean getEnableServer()
	{
		String s = getProperty(EnableServer, "false");
		return new Boolean(s).booleanValue();
	}
	
	public String getConfigFile()
	{
		String config = getProperty(ConfigFile);
		if (config != null && config.toLowerCase().startsWith("file:"))
			return config.substring(5);
		else 
			return config;
	}
	
	public String getPassword()
	{
		return password;
	}
	
	public String getKeytab()
	{
		return getProperty(Keytab);
	}
	
	public String getCacheName()
	{
		return getProperty(CacheName);
	}
	
	public String getLifetime()
	{
		return getProperty(Lifetime);
	}
	
	public String getRenewableLife()
	{
		return getProperty(RenewableLife);
	}
	
	public String getAuthenticator()
	{
		return getProperty(Authenticator);
	}
	
	public void
	setDelegation(boolean on)
	{
		put(Delegation, new Boolean(on).toString());
	}
	
	public void
	setEnableServer(boolean on)
	{
		put(EnableServer, new Boolean(on).toString());
	}
	
	public void
	setPassword(String p)
	{
		if (!p.startsWith("\"") && !p.endsWith("\"") ) {
			throw new org.omg.CORBA.BAD_PARAM("Password for authentication data must be in quotes");
		}
		password = p.substring(1,p.length()-1);
		// so if it gets written.
		put(Password, p);
	}
	
	public void
	setKeytab(String s)
	{
		put(Keytab,s);
	}
	
	public void
	setCacheName(String s)
	{
		put(CacheName,s);
	}
	
	public void
	setLifetime(String s)
	{
		put(Lifetime,s);
	}
	
	public void
	setRenewableLife(String s)
	{
		put(RenewableLife,s);
	}
	
	public void
	setAuthenticator(String s)
	{
		put(Authenticator,s);
	}
}
