//tabstop=4
//*****************************************************************************
// Project: Orbasec
//
// File:    Kerberos_Credentials.java
// Date:    March 1998
//
// -------------------------------------------------------------------------
// Copyright (C) 1998 Polar Humenn
//                    All rights reserved.
// -------------------------------------------------------------------------
// $Id$
//*****************************************************************************
package orbasec.secrep.gsskrb5;

import orbasec.krb5.*;
import orbasec.krb5.Kerberos_Kinit;

import java.util.Vector;
import java.util.Enumeration;

import org.omg.Security.*;
import org.omg.Security.SecAttribute;
import org.omg.SecurityLevel2.*;

import org.omg.Security.DelegationMode;

import orbasec.util.*;
import orbasec.corba.*;
import orbasec.corba.Opaque;

public class Kerberos_Credentials
	extends    orbasec.corba.LocalObject
	implements org.omg.SecurityLevel2.ReceivedCredentials,
	           org.omg.SecurityLevel2.TargetCredentials,
	           orbasec.seciop.SettableAttributes
{
	/**
	 * Features that this credential supports.
	 */
	orbasec.corba.SecurityFeatures features_;
	
	/**
	 * The attributes.
	 */
	SecurityAttributes  attributes_;
	
	/**
	 * The list of trusted authorities for acquring credentials
	 */
	orbasec.util.List authorities_;
	
    /**
     *  IDL:org.omg.SecurityLevel2/Credentials/get_attributes:1.0
     */
    public SecAttribute[]
    get_attributes(AttributeType[] atypes)
    {
		if (atypes == null || atypes.length == 0)
			return attributes_.attributes();
			
		return attributes_.find(atypes);
    }
    
	
    //
    // IDL:org.omg.SecurityLevel2/Credentials/set_privileges:1.0
    //
	
	// For some stupid reason, I think this is supposed to be like
	// a two phase commit. Really? So we keep the privs around until
	// the force_commit.
	Vector  privs = new Vector();
	
	// This is deprecated
	/**
	 * @deprecated
	 */
    public boolean
    set_privileges(boolean force_commit,
                   SecAttribute[]      requested_privileges,
                   AttributeListHolder actual_privileges)
    {
		return false;
    }
    
	public boolean
	set_attributes(SecAttribute[] requested_attributes,
	               AttributeListHolder actual_attributes)
	{
		// We do not support the reduction of attributes in this
		// mechanism. however, if the user calls
		// creds.set_attributes(creds.get_attributes(new SecAttribute[0],
        //                      new AttributeListHolder());
		// He should get true back.
		SecAttribute[] attrs = attributes_.attributes();
		boolean hasAll = CredUtil.equivalent(requested_attributes,
		                                     attrs);
		actual_attributes.value = attrs;
		return hasAll;
	}
								  
    //
    // IDL:org.omg.SecurityLevel2/Credentials/get_security_feature:1.0
    //
    public boolean
    get_security_feature(CommunicationDirection direction,
	                     SecurityFeature        feature)
    {
    	switch( direction.value() ) {

		case CommunicationDirection._SecDirectionRequest:
			throw new org.omg.CORBA.BAD_PARAM(
				"Request Direction not supported.",
				orbasec.corba.MinorBadParam.CommunicationDirection.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			
		case CommunicationDirection._SecDirectionReply:
			throw new org.omg.CORBA.BAD_PARAM(
				"Reply Direction not supported.",
				orbasec.corba.MinorBadParam.CommunicationDirection.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			
		case CommunicationDirection._SecDirectionBoth:
			return features_.value_of(feature);
		}
		
		throw new org.omg.CORBA.INTERNAL(
					"Bad CommunicatonDirection value.",
					orbasec.corba.MinorInternal.BadEnumValue.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
	}
	
	org.omg.Security.CredentialsType credentials_type_;
	public org.omg.Security.CredentialsType
	credentials_type()
	{
		return credentials_type_;
	}
	
	String mechanism_;
	public String /* org.omg.Security.MechanismType */
	mechanism()
	{
		return mechanism_;
	}
	
	short accepting_options_supported_;
	public short
	accepting_options_supported()
	{
		return accepting_options_supported_;
	}
	
	public void
	accepting_options_supported(short opts)
	{
		// Options cannot be more than the machanism can support 
		// orginially. This will throw a BAD_PARAM error.
		check_supported_options(options_supported,opts);
		
		// Okay. Set. Required options cannot be more than supported.
		accepting_options_supported_ = opts;
		accepting_options_required_ |= opts & accepting_options_required_;
	}
	
	short accepting_options_required_;
	public short
	accepting_options_required()
	{
		return accepting_options_required_;
	}
	
	public void
	accepting_options_required(short opts)
	{
		check_required_options(accepting_options_supported_,opts);
		accepting_options_required_ = opts;
	}
	
	short invocation_options_required_;
	public short
	invocation_options_required()
	{
		return invocation_options_required_;
	}
	
	public void
	invocation_options_required(short opts)
	{
		check_required_options(invocation_options_supported_,opts);
		invocation_options_required_ = opts;
	}
	
	short invocation_options_supported_;
	public short
	invocation_options_supported()
	{
		return invocation_options_supported_;
	}

	public void
	invocation_options_supported(short opts)
	{
		check_supported_options(options_supported, opts);
		invocation_options_supported_ = opts;
	}
	
	// For received type credentials. Assigned from security context.
	short association_options_used_;
	public short
	association_options_used()
	{
		if (_A_isOwn())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return association_options_used_;
	}
	
	// For Received type credentials. Assigned from security context
	org.omg.Security.DelegationMode delegation_mode_;
	public org.omg.Security.DelegationMode
	delegation_mode()
	{
		if (!_A_isReceived())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return delegation_mode_;
	}
		
	// For Received type credentials. Assigned from security context
	Kerberos_Credentials accepting_credentials_;
	public org.omg.SecurityLevel2.Credentials
	accepting_credentials()
	{
		if (!_A_isReceived())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return accepting_credentials_;
	}
	
	void
	_A_accepting_credentials(Kerberos_Credentials creds)
	{
		accepting_credentials_ = creds;
	}
	
	// For Received type credentials. Assigned from security context
	Kerberos_Credentials initiating_credentials_;
	public org.omg.SecurityLevel2.Credentials
	initiating_credentials()
	{
		if (!_A_isTarget())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return initiating_credentials_;
	}
	
	void
	_A_initiating_credentials(Kerberos_Credentials creds)
	{
		initiating_credentials_ = creds;
	}
	
	org.omg.Security.DelegationState delegation_state_;
	public org.omg.Security.DelegationState
	delegation_state()
	{
		if (!_A_isReceived())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return delegation_state_;
	}
	
	// Not to be used outside of package.
	void
	delegation_state(org.omg.Security.DelegationState state)
	{
		if (!_A_isReceived())
			throw new org.omg.CORBA.BAD_OPERATION(
						"Invalid on own credentials.",
						orbasec.corba.MinorBadOperation.Credentials.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		delegation_state_ = state;
	}
	
	boolean own_;
	void
	_A_setReceived()
	{
		valid_    = true;
		own_ = false;
		credentials_type_ =
			org.omg.Security.CredentialsType.SecReceivedCredentials;
	}
	
	void
	_A_setOwn()
	{
		own_ = true;
		credentials_type_ =
			org.omg.Security.CredentialsType.SecOwnCredentials;
	}
	
	void
	_A_setTarget()
	{
		own_ = false;
		credentials_type_ =
			org.omg.Security.CredentialsType.SecTargetCredentials;
	}
	
	boolean
	_A_isReceived()
	{
		return credentials_type_.value() == 
		       org.omg.Security.CredentialsType.SecReceivedCredentials.value();
	}
	
	boolean
	_A_isTarget()
	{
		return credentials_type_.value() == 
		       org.omg.Security.CredentialsType.SecTargetCredentials.value();
	}
	
	boolean
	_A_isOwn()
	{
		return credentials_type_.value() == 
		       org.omg.Security.CredentialsType.SecOwnCredentials.value();
	}
	
	/**
	 * Names the file where Kerberos credentials are kept.
	 */
	boolean       valid_ = false;
	gss_cred_id_t gss_creds = null;
	
	/**
	 * We keep a copy of the kerberos credential cache
	 * name, as if we are supporting delegation we need to
	 * save the credential cache as accepting a delegateable
	 * TGT wipes out the credcache for some reason.
	 */
	String        ccache = null;
	
	/**
	 * We keep a copy of the kerberos keytab
	 * name	 */
	String        keytab = null;
	
	/**
	 * We need to keep a copy of the Kerberos Configuration file
	 * name;
	 */
	String        conf_file_ = null;
	
	gss_cred_id_t
	get_gss_cred_id_t()
	{
		return gss_creds;
	}
	
	public void
	keytab(String kt)
	{
		if (kt != null && kt.trim().equals(""))
			keytab = null;
		else
			keytab = kt;
		
		if (keytab != null && acquired_) {
			_A_acquire_credentials(new String(_A_get_access_id_name()));
		}
	}
	
	public String
	keytab()
	{
		return keytab;
	}
	
	
	/** The minimum assocation options that are required */
	
	short min_required_mask;   
    short ic_mask;
	short options_supported;            
	/**
	 * KerberosV5 initial assocation options.
	 */
	void
	initialize_assoc_options()
	{
		// The only thing that is required is trust in client.
		min_required_mask = (short) org.omg.Security.EstablishTrustInClient.value;
							 
		ic_mask  = org.omg.Security.Confidentiality.value;
		ic_mask |= org.omg.Security.Integrity.value;
		
		// This should mirror SecurityFeatures. 
		options_supported = 0;
		options_supported |= org.omg.Security.NoDelegation.value;
		options_supported |= org.omg.Security.SimpleDelegation.value;
		options_supported |= org.omg.Security.NoProtection.value;
		options_supported |= org.omg.Security.Confidentiality.value;
		options_supported |= org.omg.Security.Integrity.value;
		options_supported |= org.omg.Security.DetectReplay.value;
		options_supported |= org.omg.Security.EstablishTrustInTarget.value;
		options_supported |= org.omg.Security.EstablishTrustInClient.value;

		accepting_options_supported_  = options_supported;
		accepting_options_required_   = 0;
		accepting_options_required_ |= org.omg.Security.EstablishTrustInTarget.value;
		accepting_options_required_ |= org.omg.Security.EstablishTrustInClient.value;

		// Minimum Required is this minus what is supported.
		min_required_mask &= options_supported;
		
		invocation_options_supported_ = options_supported;
		// Should mirror the SecurityFeatures for Kerberos
		
		// The only thing we can't turn off in Kerberos.
		invocation_options_required_ = (short) org.omg.Security.EstablishTrustInClient.value;
	}
	
	private boolean anyopts(short options, int opts)
	{
		return (options & opts) != 0;
	}
	private boolean allopts(short options, int opts)
	{
		return (options & opts) == opts;
	}
	
	/**
	 * NoProtection or IntegrityAndConfidentiality only are supported.
	 */
	boolean
	supports_QOP(QOP qop)
	{
		switch(qop.value()) {
		case QOP._SecQOPNoProtection:
			// NoProtection must be supported and I or C cannot be required.
			return anyopts(invocation_options_supported_,(int)NoProtection.value)
				   && !anyopts(invocation_options_required_,
				           Integrity.value | Confidentiality.value);
		case QOP._SecQOPIntegrity:
			// Integrity is supported and NoProtection or Confidentialtiy is
			// required.
			return anyopts(invocation_options_supported_,(int)Integrity.value)
				   && !anyopts(invocation_options_required_,
				           NoProtection.value | Confidentiality.value);
		case QOP._SecQOPConfidentiality:
			return anyopts(invocation_options_supported_,(int)Confidentiality.value)
				   && !anyopts(invocation_options_required_,
				           NoProtection.value | Integrity.value);
		case QOP._SecQOPIntegrityAndConfidentiality:
			return allopts(invocation_options_supported_,
			          Integrity.value | Confidentiality.value)
				   && !anyopts(invocation_options_required_,
				           NoProtection.value);
		default:
			throw new org.omg.CORBA.INTERNAL(
						"Bad QOP value.",
						orbasec.corba.MinorInternal.BadEnumValue.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	void
	_A_supports_invoc_options(short opts)
	{
		check_required_options(invocation_options_required_, opts);
	}
	
	private void
	check_supported_options(short supported, short opts)
	{
		// First of all opts required must be at least what is supported.
		if ( opts != (supported & opts) )
			throw new org.omg.CORBA.BAD_PARAM(
						"Association Options must be supported.",
						orbasec.corba.MinorBadParam.AssociationOptions.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
	}

	private void
	check_required_options(short supported, short opts)
	{
		// First of all opts required must be at least what is supported.
		check_supported_options(supported,opts); 
		// About the only thing you can do in kerberos is
		// require no protection or both I&C, but not both of each.
		if ( 0 != (opts & org.omg.Security.NoProtection.value)) {
			// then both I & C must be off.
			if ( 0 != (opts & ic_mask)) {
				throw new org.omg.CORBA.BAD_PARAM(
						"NoProtection or Integrity and/or Confidentiality, but not both", 
						orbasec.corba.MinorBadParam.AssociationOptions.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			}
		}
		if ( 0 != (opts & org.omg.Security.NoDelegation.value)) {
			// then Simple Delegation must be off.
			if ( 0 != (opts & org.omg.Security.SimpleDelegation.value)) {
				throw new org.omg.CORBA.BAD_PARAM(
						"NoDelegation or SimpleDelegation, but not both.",
						orbasec.corba.MinorBadParam.DelegationMode.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			}
		}
	}
	
	boolean
	supports_delegation(org.omg.Security.DelegationMode mode)
	{
		switch(mode.value()) {
		case DelegationMode._SecDelModeNoDelegation:
			return features_.no_delegation();
		case DelegationMode._SecDelModeSimpleDelegation:
			return features_.simple_delegation();
		case DelegationMode._SecDelModeCompositeDelegation:
			return features_.composite_delegation();
		default:
		throw new org.omg.CORBA.INTERNAL(
					"Bad QOP value.",
					orbasec.corba.MinorInternal.BadEnumValue.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}

	/** 
	 * Constructor always takes the cache file that is 
	 * currently in effect.
	 */
	Kerberos_Credentials(String conffile, String _keytab, String _ccache)
	{
		conf_file_ = conffile;
		
		// Initially enough for mech and name
		attributes_ = new SecurityAttributes(); 
		_A_set_mechanism_id(Kerberos_Vault.VAULT_MECHANISM);
		mechanism_ = Kerberos_Vault.VAULT_MECHANISM;
		initialize_assoc_options();
		delegation_state_ = org.omg.Security.DelegationState.SecInitiator;
		
		if (_keytab == null || _keytab.trim().equals("")) {
			accepting_options_supported_ = 0;
			accepting_options_required_  = 0;
		}
		
		//
		// Get default Kerberos type credential features.
		// We have two sets here, but we only use request
		// features for anything.
		//
		features_ = new orbasec.corba.SecurityFeatures();
		features_._A_set_from_options(invocation_options_supported_);

		//
		// Assign the gs_credential handle holder
		//
		gss_creds   = new gss_cred_id_t();
		ccache      = _ccache;
		
		keytab(_keytab);
	}
		
	/**
	 * This function is called by the principal authenticated
	 * to get it's credentials from the keytab.
	 */
	
	boolean acquired_ = false;
	boolean
	_A_acquire_credentials( String prin_name )
	{
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP, "Kerberos_Credentials._A_aquire_credentials:");
		}
		/* END DEBUG */
		int maj_stat;
		gss_int_holder min_stat       = new gss_int_holder();
		// A new gss_name_t is null, this means use default name from cache
		gss_name_t     principal_name = new gss_name_t();
		
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP, "Kerberos_Credentials._A_aquire_credentials:");
		}
		/* END DEBUG */
		
		// If we have name, use it.
		if(prin_name != null && !prin_name.trim().equals("")) {
			maj_stat = gss.import_name(min_stat, prin_name,
		                	gss.gss_nt_user_name, principal_name);

			if (maj_stat != gss.GSS_S_COMPLETE) {
				authentication_state_ = AuthenticationStatus.SecAuthFailure;
				throw new GSSError("importing name", maj_stat, min_stat.value);
			}

			gss_string_holder sname = new gss_string_holder();
			gss_OID           name_type = new gss_OID();
			maj_stat = gss.display_name(min_stat, principal_name, sname, name_type);
			if (maj_stat != gss.GSS_S_COMPLETE ) {
				authentication_state_ = AuthenticationStatus.SecAuthFailure;
				throw new GSSError("displaying server name", maj_stat, min_stat.value);
			}
			/* START DEBUG */
			if (Debug.debug) {
	    		Debug.println(Debug.SECIOP,"  Got name: " + sname.buffer() );
			}
			/* END DEBUG */
			gss_string_holder oid_name = new gss_string_holder();
			maj_stat = gss.oid_to_str(min_stat, name_type, oid_name);
			if (maj_stat != gss.GSS_S_COMPLETE) {
				authentication_state_ = AuthenticationStatus.SecAuthFailure;
				throw new GSSError("converting oid->string", maj_stat, min_stat.value);
			}
			/* START DEBUG */
			if (Debug.debug) {
				Debug.println(Debug.SECIOP,"Name type of server name is " + oid_name.buffer());
			}
			/* END DEBUG */
			// We got the access id, set it. The aquire will barf if it
			// doesn't match what's in the cache.
			_A_set_access_id(sname.buffer());
		}

		// Set the cred cache and the keytab for the credentials.
		if (gss.version.major == 1 && gss.version.minor == 0) {
			if (ccache != null)
				gss.krb_set_cache(ccache);
			if (keytab != null)
				gss.krb_set_keytab(keytab);
		} else {
			// In VERSION 1.1 and higher, having null for the ccache
			// and keytab names sets them to get them from the system
			// defaults.
			gss.krb_set_cache(ccache);
			gss.krb_set_keytab(keytab);
		}
		
		gss_OID_set    actual_mechs = new gss_OID_set();
		gss_int_holder time_rec     = new gss_int_holder();
		int designator;
		
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,"   keytab=" + keytab + " cache=" +ccache);
		}
		/* END DEBUG */
		if (keytab != null && ccache != null) {
			designator = gss.GSS_C_BOTH;
		} else if (keytab != null) {
			designator = gss.GSS_C_ACCEPT;
		} else /* ccache != null */ {
			designator = gss.GSS_C_INITIATE;
		}
		maj_stat = gss.acquire_cred(min_stat, principal_name, 0,
		                           gss.GSS_C_NO_OID_SET, // default mechanism
		                           designator,
		                           gss_creds, 
		                           actual_mechs, 
		                           time_rec);
		                           
		if (maj_stat != gss.GSS_S_COMPLETE ) {
			authentication_state_ = AuthenticationStatus.SecAuthFailure;
			throw new GSSError("acquiring_credentials", maj_stat, min_stat.value);
		}
		
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,"gss_creds= 0x" + Integer.toHexString(gss_creds.handle));
		}
		/* END DEBUG */
		// If we weren't given a name, i.e. getting it from the cache,
		// we inquire the creds for it.
		if(prin_name == null || prin_name.trim().equals("")) {
			_A_set_access_id(_A_inquire_name());
		}
		valid_ = true;
		acquired_ = true;
		org.omg.CORBA.StringHolder err = new org.omg.CORBA.StringHolder();
		
		authorities_ = Kerberos_Vault.getOwnAuthorities();
		
		if (Kerberos_Vault.verifyAuthority(_A_get_issuer_id(),authorities_,err))
			authentication_state_ = AuthenticationStatus.SecAuthSuccess;
		else
			throw new org.omg.CORBA.BAD_PARAM(
							err.value,
							orbasec.corba.MinorBadParam.TrustedAuthority.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return valid_;
	}
	
	public Credentials
    copy()
    {
    	Kerberos_Credentials creds = new Kerberos_Credentials(this.conf_file_,
		                                  this.keytab, this.ccache);
    
    	creds.can_be_delegated_    		 = this.can_be_delegated_;
    	creds.features_                  = this.features_;
		creds.attributes_          		 = this.attributes_;
	    creds.acquired_                  = this.acquired_;
	    creds.valid_               		 = this.valid_;
	    creds.ccache              		 = this.ccache;
	    creds.conf_file_              	 = this.conf_file_;
	    creds.keytab              		 = this.keytab;
		creds.gss_creds           		 = this.gss_creds;
		creds.accepting_options_supported_ = this.accepting_options_supported_;
		creds.accepting_options_required_  = this.accepting_options_required_;
		creds.invocation_options_supported_ = this.invocation_options_supported_;
		creds.invocation_options_required_ = this.invocation_options_required_;
		creds.association_options_used_  = this.association_options_used_;
		creds.delegation_state_   		 = this.delegation_state_;
		creds.mechanism_          		 = this.mechanism_;
		creds.delegation_mode_           = this.delegation_mode_;
		creds.credentials_type_          = this.credentials_type_;
		creds.authentication_state_      = this.authentication_state_;
		creds.authorities_               = this.authorities_;
		return creds;
    }

	public void
	destroy()
	{
	}
	
    //
    // IDL:org.omg.SecurityLevel2/Credentials/is_valid:1.0
    //
    public boolean
    is_valid(org.omg.TimeBase.UtcTHolder expiry_time)
    {
		try {
			return internal_is_valid(expiry_time);
		} catch (GSSError gsserr) {
			throw new org.omg.CORBA.INTERNAL(
				"GSS Error : " + gsserr.getMessage(),
				orbasec.corba.MinorInternal.GSSError.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_MAYBE);
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}
	}
	
    private boolean
    internal_is_valid(org.omg.TimeBase.UtcTHolder expiry_time)
    {
    	if (   valid_ 
		    && (!this._A_isOwn() ||
			    (authentication_state_ == AuthenticationStatus.SecAuthSuccess))
			&& !expired(expiry_time) ){
    		return true;
		} else {
    		return false;
		}
    }
	
	private boolean
	expired( org.omg.TimeBase.UtcTHolder expiry_time )
	{
 		//
		// If we are supporting delegation we need to make sure that
		// the correct cache file for these credentials is the default.
		//
		
	   	int            maj_stat;
    	gss_int_holder min_stat     = new gss_int_holder();
		gss_int_holder lifetime_ret = new gss_int_holder();
		
    	maj_stat = gss.inquire_cred( min_stat,
	              				 	 gss_creds,
                  				 	 null,  	// gss_name_t name
                  				 	 lifetime_ret,
                  				 	 null,  	// gss_int_holder cred_usage,
                  				 	 null); 	// gss_OID_set    mechanisms);
        
        if (maj_stat != gss.GSS_S_COMPLETE) {
        	throw new GSSError("inquire_cred", maj_stat, min_stat.value);
        }
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,"Lifetime for creds is " + lifetime_ret.value);
		}
		/* END DEBUG */
       
		// What form is this lifetime in?
		// I am assuming seconds!
    	if (expiry_time != null) {
			expiry_time.value = orbasec.corba.U.time2utct(new java.util.Date().getTime() + lifetime_ret.value);
    	}
		
		boolean is_expired = false; // lifetime_ret.value > 0;
		
		// record this in the state
		if ( is_expired ){
			authentication_state_ = AuthenticationStatus.SecAuthExpired;
		}
		
    	return is_expired;
	}

    //
    // IDL:org.omg.SecurityLevel2/Credentials/refresh:1.0
    //
    public boolean
    refresh( byte refresh_data[] )
    {

		try {
    	if (_A_isOwn())
    		return Kerberos_Kinit.refresh(conf_file_,ccache);
    	else if (_A_isReceived())
    		return false;
    	else
    		return false;
		} catch (GSSError gsserr) {
			throw new org.omg.CORBA.BAD_PARAM(
				"GSS Error : " + gsserr.getMessage(),
				orbasec.corba.MinorBadParam.GSSError.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}
    }
    
	public String
	_A_inquire_name()
	{
    	int            maj_stat;
    	gss_int_holder min_stat     = new gss_int_holder();
		gss_int_holder lifetime_ret = new gss_int_holder();
		gss_int_holder cred_usage   = new gss_int_holder();
		gss_OID_set    oid_set      = new gss_OID_set();
		gss_OID        oid          = new gss_OID();
		gss_name_t     name         = new gss_name_t();
		
    	maj_stat = gss.inquire_cred( min_stat,
	              				 	 gss_creds,
                  				 	 name,
                  				 	 lifetime_ret,
                  				 	 cred_usage,  	
                  				 	 oid_set); 	
        
        if (maj_stat != gss.GSS_S_COMPLETE) {
        	throw new GSSError("inquire_cred", maj_stat, min_stat.value);
        }
        
        gss_string_holder nameh = new gss_string_holder();
        
		maj_stat = gss.display_name(min_stat, name, nameh, oid);
		if (maj_stat != gss.GSS_S_COMPLETE) {
			throw new GSSError("displaying name", maj_stat, min_stat.value);
	    }
	    
		return nameh.buffer();
	}
		
    public String
    _A_inquire()
    {
    	int            maj_stat;
    	gss_int_holder min_stat     = new gss_int_holder();
		gss_int_holder lifetime_ret = new gss_int_holder();
		gss_int_holder cred_usage   = new gss_int_holder();
		gss_OID_set    oid_set      = new gss_OID_set();
		gss_OID        oid          = new gss_OID();
		gss_name_t     name         = new gss_name_t();
		
    	maj_stat = gss.inquire_cred( min_stat,
	              				 	 gss_creds,
                  				 	 name,
                  				 	 lifetime_ret,
                  				 	 cred_usage,  	
                  				 	 oid_set); 	
        
        if (maj_stat != gss.GSS_S_COMPLETE) {
        	throw new GSSError("inquire_cred", maj_stat, min_stat.value);
        }
        
        gss_string_holder nameh = new gss_string_holder();
        
		maj_stat = gss.display_name(min_stat, name, nameh, oid);
		if (maj_stat != gss.GSS_S_COMPLETE) {
			throw new GSSError("displaying name", maj_stat, min_stat.value);
	    }
	    
        return "Credential : " + gss_creds.handle + "\n" +
               "   name = " + nameh.buffer() + "\n" +
               "   lifetime = " + new java.util.Date(new java.util.Date().getTime()+lifetime_ret.value) + "\n" +
               "   usage    = " + cred_usage.value + "\n"
               ;
    }
    
	SecAttribute
	_A_get_access_id()
	{
		return attributes_.find_first(AttrDef.AccessId);
	}
	
	void
	_A_set_access_id(SecAttribute att)
	{
		// This better be of type ((0,1),2)
		attributes_.replace_or_add(att);
	}
	
	final static Opaque
	_A_subjectOf(byte[] kerberos_name)
	{
		return _A_subjectIdOf(new String(kerberos_name));
	}
	
	final static Opaque
	_A_issuerOf(byte[] kerberos_name)
	{
		return _A_issuerIdOf(new String(kerberos_name));
	}
	
	final static Opaque
	_A_subjectIdOf(String kerberos_name)
	{
		return Opaque.encodeKerberosName(kerberos_name);
	}
	
	final static Opaque
	_A_issuerIdOf(String kerberos_name)
	{
		String issuer = "krbtgt/";
		
		issuer += kerberos_name.substring(kerberos_name.lastIndexOf('@')+1);
		issuer += "@";
		issuer += kerberos_name.substring(kerberos_name.lastIndexOf('@')+1);
		
		return Opaque.encodeKerberosName(issuer);
	}
	
	void
	_A_set_access_id(String name)
	{
		Opaque kissuer, ksubject;
		kissuer  = _A_issuerIdOf(name);
		ksubject = _A_subjectIdOf(name);
		
		attributes_.replace_or_add(AttrDef.genAccessId(kissuer,ksubject));
		attributes_.replace_or_add(AttrDef.genSubjectId(ksubject));
		attributes_.replace_or_add(AttrDef.genIssuerId(kissuer));
	}

	void
	_A_set_access_id(byte[] name)
	{
		// We can short cut.
		_A_set_access_id(new String(name));
	}

	byte[]
	_A_get_access_id_name()
	{
		try {
			return Opaque.decode(_A_get_access_id().value).getRawBytes();
		} catch (Opaque.CodingException ex) {
			throw new org.omg.CORBA.INTERNAL( 
					"Opaque Coding Error.",
					orbasec.corba.MinorInternal.ORBAsecError.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	Opaque
	_A_get_issuer_id()
	{
		try {
		return Opaque.decode(attributes_.find_first(AttrDef.IssuerId).value);
		} catch (Opaque.CodingException ex) {
			throw new org.omg.CORBA.INTERNAL( 
					"Opaque Coding Error.",
					orbasec.corba.MinorInternal.ORBAsecError.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	Opaque
	_A_get_subject_id()
	{
		try {
		return Opaque.decode(attributes_.find_first(AttrDef.SubjectId).value);
		} catch (Opaque.CodingException ex) {
			throw new org.omg.CORBA.INTERNAL( 
					"Opaque Coding Error.",
					orbasec.corba.MinorInternal.ORBAsecError.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	SecAttribute
	_A_get_mechanism_id()
	{
		return attributes_.find_first(AttrDef.Mechanism);
	}
	
	void
	_A_set_mechanism_id(SecAttribute att)
	{
		attributes_.replace_or_add(att);
	}
	
	void
	_A_set_mechanism_id(String name)
	{
		_A_set_mechanism_id(_A_define_mechanism_id(name));
	}

	SecAttribute
	_A_define_mechanism_id(String id)
	{
		return AttrDef.genMechanism(id);
	}
	
	boolean can_be_delegated_;
	boolean
	_A_can_be_delegated()
	{
		return can_be_delegated_;
	}
	
	void
	_A_set_simple_delegate()
	{
		delegation_mode_ =
			org.omg.Security.DelegationMode.SecDelModeSimpleDelegation;
  		can_be_delegated_ = true;
  		features_._A_no_delegation(false);
  		features_._A_simple_delegation(true);
		invocation_options_supported_ |= org.omg.Security.SimpleDelegation.value;
	}
	
	void
	_A_set_no_delegate()
	{
		delegation_mode_ =
			org.omg.Security.DelegationMode.SecDelModeNoDelegation;
		can_be_delegated_ = false;
  		features_._A_no_delegation(true);
  		features_._A_simple_delegation(false);
  		features_._A_composite_delegation(false);
		invocation_options_supported_ &= ~org.omg.Security.SimpleDelegation.value;
	}
	
	public String
	toString()
	{
		return CredUtil.toString(this);
	}
	
	// We are going to need this for now.
	//
	// We need to be able to add the "Channel Source or Target" to the
	// credentials. They wont get passed anywhere.
	//
	public void
	set_policy_attributes(String enclave, String domain, String appname)
	{
	}
					  
	static AttributeType[] Unsettable;
	static {
	    /**
		 * These attribute types cannot be set in any credentials
		 * by set_privileges();
		 */
		Unsettable = new AttributeType[] {
			CredUtil.genAttributeType(0,0,0), // Mechanism
		};
	}
	
	static boolean
	can_set(AttributeType t)
	{
		for( int i = 0; i < Unsettable.length; i++) {
			if (CredUtil.equals(t,Unsettable[i]))
				return false;
		}
		return true;
	}
	
	static boolean
	can_set(SecAttribute attr)
	{
		return can_set(attr.attribute_type);
	}
	
	AuthenticationStatus authentication_state_ = 
		AuthenticationStatus.SecAuthContinue;
	
	public AuthenticationStatus
	authentication_state()
	{
		try {
			org.omg.TimeBase.UtcTHolder expiry_time = 
				new org.omg.TimeBase.UtcTHolder();

			if ( expired(expiry_time) ){
				// already done in expired() check:
				//authentication_state_ = AuthenticationStatus.SecAuthExpired;
			}
			return authentication_state_;
		} catch (GSSError gsserr) {
			throw new org.omg.CORBA.INTERNAL(
				"GSS Error : " + gsserr.getMessage(),
				orbasec.corba.MinorInternal.GSSError.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_MAYBE);
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}
	}
	
	// Vendor Specific.
	public void
	_A_add_attribute(SecAttribute att)
	{
		attributes_.add(att);
	}
	
}
