//tabstop=4
//*****************************************************************************
// Project: Orbasec
//
// File:    Kerberos_Vault.java
// Date:    March 98
// Author:  Polar Humenn
//
//-----------------------------------------------------------------------------
// Copyright (C) 1998 Polar Humenn. All Rights Reserved.
//-----------------------------------------------------------------------------
// $Id$
//*****************************************************************************

package orbasec.secrep.gsskrb5;

import orbasec.krb5.*;
import orbasec.corba.MechUtil;
import orbasec.corba.CredUtil;
import orbasec.corba.Opaque;
import orbasec.util.*;

import org.omg.Security.AssociationStatus;
import org.omg.Security.AuthenticationStatus;
import org.omg.Security.MechandOptions;
import org.omg.Security.OptionsDirectionPair;
import org.omg.Security.DelegationMode;
import org.omg.Security.CommunicationDirection;
import org.omg.Security.OpaqueHolder;
import org.omg.Security.SecAttribute;
import org.omg.Security.OpaqueBuffer;
import org.omg.Security.OpaqueBufferHolder;
import org.omg.Security.ChannelBindings;

import org.omg.SecurityLevel2.Credentials;
import org.omg.SecurityLevel2.CredentialsHolder;

import org.omg.SecurityReplaceable.SecurityContextHolder;
import org.omg.SecurityReplaceable.ServerSecurityContextHolder;
import org.omg.SecurityReplaceable.ClientSecurityContextHolder;

//----------------------------------------------------------------------/
// Kerberos_Vault
/**
 * This class provides methods for establishing security contexts between
 * clients and targets.
 * 
 * @author  Polar Humenn
 * @version $Revision$
 * @see     
 */
// Implementation notes:  
// 
//----------------------------------------------------------------------/
public class Kerberos_Vault
    extends    orbasec.corba.LocalObject
	implements org.omg.SecurityReplaceable.Vault
{
	boolean DELEGATION_SUPPORTED = true;
	
	static orbasec.krb5.Kerberos_Kinit kinit_ =
		new orbasec.krb5.Kerberos_Kinit();
	final static String VAULT_MECHANISM = "Kerberos_MIT";
	
    //----------------------------------------------------------------------
    //  private attributes
    //----------------------------------------------------------------------
    private MechandOptions[] mech_types_and_options = new MechandOptions[1];
	
	private boolean use_session_ = false;

    //----------------------------------------------------------------------/
    // Unix_Vault
    /**
     * constructor
     * 
     */
    // 
    //----------------------------------------------------------------------/
    public 
    Kerberos_Vault()
    {
        // Unix mechanism and its supported options
        short /* AssociationOptions */ assoc_opts = ( short )
        // GSS-KerberosV5 that we are using supports these options
                    ( org.omg.Security.NoProtection.value |
                      org.omg.Security.Integrity.value |
                      org.omg.Security.Confidentiality.value |
                      org.omg.Security.DetectReplay.value |
                      org.omg.Security.DetectMisordering.value |
                      org.omg.Security.EstablishTrustInTarget.value |
                      org.omg.Security.EstablishTrustInClient.value |
					  org.omg.Security.NoDelegation.value |
					  org.omg.Security.SimpleDelegation.value ) ;

        mech_types_and_options[0] = new MechandOptions( VAULT_MECHANISM, 
                                                        assoc_opts ) ;
    }
	
	Kerberos_Credentials[]
	find_creds(org.omg.SecurityLevel2.Credentials[] cred_list)
	{
		org.omg.SecurityLevel2.Credentials[] creds_list =
			CredUtil.find_credentials(cred_list,VAULT_MECHANISM);
		if (creds_list == null || creds_list.length == 0) {
			/* START DEBUG */
			if (Debug.debug) {
					Debug.println(Debug.SECIOP,"Kerberos_Vault:no_credentials");
			}
			/* END DEBUG */
			throw new org.omg.CORBA.BAD_PARAM(
							"No Kerberos credentials.",
							orbasec.corba.MinorBadParam.Credentials.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
		
		java.util.Vector found_creds = new java.util.Vector();
		
		for(int i=0; i < creds_list.length; i++) {

    		//
    		// If these creds are expired, see if we can refresh.
    		// If the are received, we probably cannot.
    		//
    		if (!creds_list[i].is_valid(null)) {
    			if (!creds_list[i].refresh(new byte[0])) { // what refresh_data?
				throw new org.omg.CORBA.BAD_PARAM(
								"Kerberos Credentials expired.",
								orbasec.corba.MinorBadParam.Credentials.value(),
								org.omg.CORBA.CompletionStatus.COMPLETED_NO);
    			}
    		}
			try {
				found_creds.addElement(((Kerberos_Credentials) creds_list[i]).copy());
			} catch (ClassCastException ex) {
				throw new org.omg.CORBA.BAD_PARAM(
								"Class Cast Exception on Kerberos Credentials.",
								orbasec.corba.MinorBadParam.Credentials.value(),
								org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			}
		}
		Kerberos_Credentials[] ret = 
			new Kerberos_Credentials[found_creds.size()];
		found_creds.copyInto(ret);
		return ret;
	}
	
	Kerberos_Credentials
	check_creds( org.omg.SecurityLevel2.Credentials creds )
	{
		if ( !MechUtil.mechSupportsMech(creds.mechanism(),VAULT_MECHANISM) ) {
			throw new org.omg.CORBA.BAD_PARAM(
							"No Kerberos Credentials.",
							orbasec.corba.MinorBadParam.Credentials.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
    	
		if (!creds.is_valid(null)) {
    		if (!creds.refresh(new byte[0])) { // what refresh_data?
			throw new org.omg.CORBA.BAD_PARAM(
							"Kerberos Credentials expired.",
							orbasec.corba.MinorBadParam.Credentials.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
    		}
    	}
		try {
			return (Kerberos_Credentials) creds.copy();
		} catch (ClassCastException ex) {
			throw new org.omg.CORBA.BAD_PARAM(
							"Class Cast Exception on Kerberos Credentials.",
							orbasec.corba.MinorBadParam.Credentials.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		}
	}
	
	short /* org.omg.Security.AssociationOptions */
	get_association_options(OptionsDirectionPair[] association_options)
	{
		if (association_options == null || association_options.length < 1) 
			throw new org.omg.CORBA.BAD_PARAM(
							"Bad Options Direction Pair.",
							orbasec.corba.MinorBadParam.AssociationOptions.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);

		if (association_options.length != 1 || 
		    association_options[0].direction.value() != 
				CommunicationDirection._SecDirectionBoth) 
			throw new org.omg.CORBA.BAD_PARAM(
							"Only one set of association options supported, with designation SecDirectionBoth.",
							orbasec.corba.MinorBadParam.AssociationOptions.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		return association_options[0].options;
	}
	
    //------------------------------------------------------------------/
    // init_security_context
    /**
     * This method is by a client to initiate the establishment
     * of the security association with the target.
     *
     * @param  cred_list            The credentials to be used to establish  
     *                              the security association.
     * @param  target_security_name The security name of the target as set
     *                              in its object reference.
     * @param  target               The target object reference.
     * @param  delegation_mode      The mode of delegation.
     * @param  association_options  A sequence of one or more pairs of 
     *                              secure association options and direction.
     * @param  security_token       The token to be transmitted to the target
     *                              to establish security association.
     * @param  security_context     The security context at the client which 
     *                              represents the shared security context 
     *                              between client and target as identified
     *                              by the specified security target name.
     *
     * @return AssociationStatus    The association status
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/
    public AssociationStatus
    init_security_context(Credentials            creds,
                          byte[] /* SecurityName */ target_security_name,
                          org.omg.CORBA.Object   target,  //@@@@ SHOULD GO AWAY!
                          DelegationMode         delegation_mode,
                          OptionsDirectionPair[] association_options,
                          String                 mechanism,
                          byte[]                 mech_data,
                          ChannelBindings        chan_bindings,
                          OpaqueBufferHolder     security_token,
                          ClientSecurityContextHolder  security_context )
    {
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,"Kerberos_Vault:init_security_context");
		}
		/* END DEBUG */
		// Mechanism has beed determined to be kerberos "17,11"
		// Find the kerberos credentials in the list.
		Kerberos_Credentials kerberos_creds = check_creds( creds );
		
		short /* AssociationOptions */ options =
			get_association_options(association_options);
		Kerberos_SecurityContext csc =
			new Kerberos_SecurityContext(
				kerberos_creds,
				target_security_name,
				delegation_mode,
			    options,
				mechanism,
				mech_data,
				chan_bindings);

		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,"Kerberos_Vault: " + creds);
			Debug.println(Debug.SECIOP,"Kerberos_Vault:delegation value : " + delegation_mode.value());
		}
		/* END DEBUG */
    	
		OpaqueHolder      out_token = new OpaqueHolder();
		AssociationStatus ret       = AssociationStatus.SecAssocFailure;
		
		try {
			ret = csc.init_context(target_security_name,
			                 association_options,
			                 delegation_mode,
			                 out_token);
		} catch( GSSError gsserr) {
			throw new org.omg.CORBA.NO_PERMISSION(
							"GSS Error: " + gsserr.getMessage(),
							orbasec.corba.MinorNoPermission.InitSecurityContext.value(),
							org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}

        // create an OpaqueBuffer with the output token as the buffer value
		security_token.value          = new OpaqueBuffer();
		security_token.value.buffer   = out_token.value;
		security_token.value.startpos = 0;
		security_token.value.endpos   = out_token.value.length;
		
        security_context.value   = csc;
        
        return ret;
    }

    //------------------------------------------------------------------/
    // accept_security_context
    /**
     * This method is used at the client to initiate the establishment
     * of the security association with the target.
     *
     * @param  cred_list        The credentials to be used to establish the 
     *                          security association
     * @param  in_token         The token to be transmitted from the client
     *                          to establish security association
     * @param  out_token        The token to be transmitted to the client, if
     *                          establishment of the security association is 
     *                          not complete
     * @param  security_context The security context at the target which 
     *                          represents the shared security context 
     *                          between client and target as identified
     *                          by the specified security target name
     *
     * @return  AssociationStatus The association status
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/
    public AssociationStatus
    accept_security_context(Credentials[]               use_cred_list,
                            ChannelBindings             chan_bindings,
                            byte[]                      in_token,
                            OpaqueBufferHolder          out_token,
                            ServerSecurityContextHolder security_context )
    {
		/* START DEBUG */
		if (Debug.debug) {
			Debug.println(Debug.SECIOP,
				"KerberosVault.accept_security_context: Number of Creds" 
				+ use_cred_list.length);
		}
		/* END DEBUG */
 		Kerberos_Credentials[] creds_list = find_creds(use_cred_list);
		StringBuffer errmsg = new StringBuffer("GSS Error:");
		
		for (int i = 0; i < creds_list.length; i++) {
			Kerberos_SecurityContext ctx   = 
				new Kerberos_SecurityContext(creds_list[i],chan_bindings);

    		AssociationStatus ret;
			OpaqueHolder      opaque_holder = new OpaqueHolder();
			try {	
 				ret = ctx.accept_context(in_token, opaque_holder);
		    	/* START DEBUG */
				if (Debug.debug) {
					Debug.println(Debug.SECIOP,"Kerberos.ctx_accept_context: returns " +
				            	  ret.value());
				}
				/* END DEBUG */
				if (ret.value() == AssociationStatus._SecAssocFailure) {
					errmsg.append("Credentials["+i+"]: AssocFailure\n");
					continue;
				}
        		// create an OpaqueBuffer with the output token as the buffer value
				out_token.value          = new OpaqueBuffer();
				out_token.value.buffer   = opaque_holder.value;
				out_token.value.startpos = 0;
				out_token.value.endpos   = opaque_holder.value.length;

    			security_context.value = ctx;
        		return ret;
    		} catch (GSSError gsserr) {
		    	/* START DEBUG */
				if (Debug.debug) {
					Debug.println(Debug.SECIOP,"Kerberos.accept_security_context: " +
				            	  "GSS error : " + gsserr.getMessage());
				}
				/* END DEBUG */
				errmsg.append("Credentials[");
				errmsg.append(i);
				errmsg.append("]: ");
				errmsg.append(gsserr.getMessage());
				errmsg.append("\n");
			} catch(org.omg.CORBA.COMM_FAILURE e) {
				errmsg.append("Credentials[");
				errmsg.append(i);
				errmsg.append("]: ");
				errmsg.append(e);
				errmsg.append("\n");
			}
		    
		}
		throw new org.omg.CORBA.NO_PERMISSION(
						errmsg.toString(),
						orbasec.corba.MinorNoPermission.AcceptSecurityContext.value(),
						org.omg.CORBA.CompletionStatus.COMPLETED_NO);
    }

    //------------------------------------------------------------------/
    // get_supported_mechs
    /**
     * 
     * @return  MechandOptions[] mechanism types supported by Caribou_Vault
     *                           and the association options these support
     */
    // Implementation notes:  
    // 
    //------------------------------------------------------------------/
    public MechandOptions[]
    get_supported_mechs()
    {
        return mech_types_and_options;
    }
	
	// Damn signed bytes! -(256-hex) is two's complement.
	byte[][] supported_oids_ = {
		{ 0x2B, 0x05, 0x01, 0x05, 0x02 },
  		/* this is the official, rfc-specified OID */
		{ 0x2A,(byte) -(256-0x86), 0x48, (byte) -(256-0xF7), 0x12, 0x01, 0x02, 0x02 },
   		/* this is the v2 assigned OID */
		{ 0x2A,(byte) -(256-0x86), 0x48, (byte) -(256-0x86), (byte) -(256-0xF7), 0x12, 0x01, 0x02, 0x03},
   		/* this is the official, rfc-specified OID again */
		{ 0x2A, (byte) -(256-0x86), 0x48, (byte) -(256-0x86), (byte) -(256-0xF7), 0x12, 0x01, 0x02, 0x02},
	};
	
	public byte[][]
	supported_mech_oids()
	{
		return supported_oids_;
	}
	
	protected void
	use_session( boolean session )
	{
		this.use_session_ = session; // not using this...yet...
	}
	
	//------------------------------------------------------------------/
	// acquire_credentials
	/**
	 * This method authenticates the principal using the desired
	 * method and creates the credentials.
	 *
	 * @param method             The method that we are using, such as 
	 *                           password.
	 * @param security_name      The name of the principal.
	 * @param auth_data          Authenitication data, such as password.
	 * @param privileges         Desired Privileges, such as role, etc.
	 * @param creds              The credentials returned.
	 * @param continuation_data  This is return as a token needed for
	 *                           continue_authentication.
	 * @param auth_specific_data This is also returned in response for
	 *                           a continue. Might have to be added
	 *                           to, might be a message, depends on
	 *                           the method used.
	 *
	 * @return The success, continue, or failure indication of the
	 *         authentication process.
	 */
	// Implementation notes:  
	//   We need to define and switch off the method. Constants are
	//   defined above.
	//------------------------------------------------------------------/
	public AuthenticationStatus
	acquire_credentials( int                method,
	                     String             mechanism,
                  		 byte[] 			security_name, // should this be here?
                  		 byte[] 			auth_data,
                  		 SecAttribute[] 	privileges,
                  		 CredentialsHolder  creds,
                  		 OpaqueHolder		continuation_data,
                  		 OpaqueHolder		auth_specific_data )
    {
    	// We know the method is "KerberosV5" and the security name
    	// is the principal id. The auth_data 
    	// Contains the following attributes
    	//  keytab= <file where this principal is kept.>
    	//  cache_name= <file where the credentials are cacched>.
    	//  auth_name= One different from the security name.
    	//  mechanism= One of "des-cbc-crc" (only one).
    	//  lifetime= <number>[s|m|h|d]
    	//  delegation=[true|false]
    	//  renewable_life= <number>[s|m|h|d]
    	//  password= !<password>EOL
    	//             
		
		// allow null or empty auth_data byte array 
		// (in case we acquire creds via kerberos session)
    	AuthData ad;
		if ( auth_data != null && auth_data.length != 0 ){
			ad = new AuthData(auth_data);
		} else {
			ad = new AuthData();
		}
	
		// allow null or empty security_name byte array
		// (in case we acquire creds via kerberos session)
		String auth_name = "";
		if ( security_name != null && security_name.length != 0 ){
			try {
				Opaque name = Opaque.decode(security_name);
    			auth_name   = name.toString();
			} catch (Exception e) {
				throw new org.omg.CORBA.DATA_CONVERSION(
					"Opaque encoding error.",
					orbasec.corba.MinorDataConversion.OpaqueEncoding.value(),
					org.omg.CORBA.CompletionStatus.COMPLETED_NO);
			}
		}
		
		try {
    	boolean okay      = false;
		boolean write_to_keytab = false;
		String pw = ad.getPassword();
		if( pw != null && pw.length() > 0 )
			write_to_keytab = ad.getEnableServer();
		
		okay = Kerberos_Kinit.getCredentials(
			                           ad.getConfigFile(),
									   ad.getKeytab(),
									   ad.getCacheName(),
									   auth_name,
									   ad.getPassword(),
									   write_to_keytab,
									   ad.getDelegation(),
									   ad.getLifetime(),
									   ad.getRenewableLife());
    	
    	if (okay) {
    		// We can use a short cut to setting this.
    		Kerberos_Credentials cred = 
    			new Kerberos_Credentials(ad.getConfigFile(),
				                         ad.getKeytab(),
										 ad.getCacheName());
    		
    		// What we should do here is call set privileges
    		// with force_commit true. However, we'll short cut
    		// it since we know what credentials type we are
    		// working with.
    		
    		cred._A_acquire_credentials(auth_name);
    		
    		if (ad.getDelegation())
    			cred._A_set_simple_delegate();
    	
			cred._A_setOwn();
    		creds.value = cred;
    		
    		return AuthenticationStatus.SecAuthSuccess;
    	}
    	} catch (GSSError e) {
			throw new org.omg.CORBA.NO_PERMISSION(
				e.getMessage(),
				orbasec.corba.MinorNoPermission.GSSError.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_NO);
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}
    	return AuthenticationStatus.SecAuthFailure;
	}
	
	//------------------------------------------------------------------/
	// continue_acquire
	/**
	 * This method continues acquiring based on the
	 * continuation data.
	 *
	 * @param response_data      Extra data needed to continue the
	 *                           authentication process.
	 * @param creds              The credentials returned.
	 * @param continuation_data  This is return as a token needed for
	 *                           another continue_authentication.
	 * @param auth_specific_data This is also returned in response for
	 *                           a continue. Might have to be added
	 *                           to, might be a message, depends on
	 *                           the method used.
	 * @return The success, continue, or failure indication of the
	 *         authentication process.
	 */
	//------------------------------------------------------------------/
	public AuthenticationStatus
	continue_acquisition(
               byte[]            response_data,
               Credentials       creds,
               OpaqueHolder      continuation_data,
               OpaqueHolder      auth_specific_data)
    {
		throw new org.omg.CORBA.NO_IMPLEMENT(
			"Continue_acquisition not implemented by this GSS Kerberos Vault.");
    }

	//------------------------------------------------------------------/
	// get_supported_authen_methods
	/**
	 * This operation returns the authentication methods
	 * that are valid for a particular mechanism that the
	 * Vault object supports.  This operation raises a
	 * CORBA::BAD_PARAM exception of the vault does not
	 * support the mechanism.
	 */
	//------------------------------------------------------------------/
	public int[]
	get_supported_authen_methods(
		String     mechanism )
	{
		try {
			int rval[] = { 0 };  // all we can do for now!
			if ( MechUtil.mechSupportsMech(mechanism,VAULT_MECHANISM ) ){
				return rval; 
			}
		} catch (org.omg.CORBA.SystemException ex) {
			throw ex;
		} catch (java.lang.Exception jex) {
			throw new org.omg.CORBA.UNKNOWN(
					"Other Exception : " + jex.toString());
		}
		throw new org.omg.CORBA.BAD_PARAM(
				"Unknown Mechanism for Kerberos Vault, " + mechanism,
				orbasec.corba.MinorBadParam.BadValue.value(),
				org.omg.CORBA.CompletionStatus.COMPLETED_NO);
	}

 	/**
	 * Returns in list form the own_trusted_authorities from the 
	 * trusted authority policy.
	 */
	final static orbasec.util.List
	getOwnAuthorities()
	{
		// Makes this dependent on the SL2.java build.
		org.omg.SecurityLevel2.Current current = 
							orbasec.SL2.get_current();
		
		org.omg.CORBA.Policy tap;
		try {
			tap = current.get_policy(
				orbasec.SecLev2.SecTrustedAuthorityPolicy.value);
		} catch (org.omg.CORBA.INV_POLICY e) {
			tap = new orbasec.corba.TrustedAuthorityPolicy(null,null,null);
		}
		orbasec.SecLev2.TrustedAuthorityPolicy trusted_auth_policy_ = 
			orbasec.SecLev2.TrustedAuthorityPolicyHelper.narrow(tap);
		orbasec.SecLev2.TrustedAuthority[] trusted_auths = 
					trusted_auth_policy_.own_trusted_authorities();
		return makeAuthoritiesList(trusted_auths);
	}
	
 	/**
	 * Returns in list form the own_trusted_authorities from the 
	 * trusted authority policy.
	 */
	final static orbasec.util.List
	getServerPeerAuthorities()
	{
		// Makes this dependent on the SL2.java build.
		org.omg.SecurityLevel2.Current current = 
							orbasec.SL2.get_current();
		
		org.omg.CORBA.Policy tap;
		try {
			tap = current.get_policy(
				orbasec.SecLev2.SecTrustedAuthorityPolicy.value);
		} catch (org.omg.CORBA.INV_POLICY e) {
			tap = new orbasec.corba.TrustedAuthorityPolicy(null,null,null);
		}
		orbasec.SecLev2.TrustedAuthorityPolicy trusted_auth_policy_ = 
			orbasec.SecLev2.TrustedAuthorityPolicyHelper.narrow(tap);
		orbasec.SecLev2.TrustedAuthority[] trusted_auths = 
					trusted_auth_policy_.server_peer_trusted_authorities();
		return makeAuthoritiesList(trusted_auths);
	}
	
 	/**
	 * Returns in list form the own_trusted_authorities from the 
	 * trusted authority policy.
	 */
	final static orbasec.util.List
	getClientPeerAuthorities()
	{
		// Makes this dependent on the SL2.java build.
		org.omg.SecurityLevel2.Current current = 
							orbasec.SL2.get_current();
		
		org.omg.CORBA.Policy tap;
		try {
			tap = current.get_policy(
				orbasec.SecLev2.SecTrustedAuthorityPolicy.value);
		} catch (org.omg.CORBA.INV_POLICY e) {
			tap = new orbasec.corba.TrustedAuthorityPolicy(null,null,null);
		}
		orbasec.SecLev2.TrustedAuthorityPolicy trusted_auth_policy_ = 
			orbasec.SecLev2.TrustedAuthorityPolicyHelper.narrow(tap);
		orbasec.SecLev2.TrustedAuthority[] trusted_auths = 
					trusted_auth_policy_.client_peer_trusted_authorities();
		return makeAuthoritiesList(trusted_auths);
	}
	
	private final static orbasec.util.List makeAuthoritiesList(
		orbasec.SecLev2.TrustedAuthority[] trusted_auths )
	{ 
		orbasec.util.List authorities = orbasec.util.ListS.list();
		// Get all the trusted authorities for "Kerberos" mechanism type.
		for(int i = 0; i < trusted_auths.length; i++ ) {
			if (trusted_auths[i].mechanism.startsWith("Kerberos")) {
				authorities = orbasec.util.ListS.cons(
								trusted_auths[i],
								authorities);
			}
		}
		return authorities.reverse();
	}
	
	//
	// Helper functions used by Credentials and SecurityContext.
	//
	final static boolean
	verifyAuthority(Opaque issuer, orbasec.util.List authorities)
	{
		return verifyAuthority(issuer,authorities,null);
	}
	
	final static boolean
	verifyAuthority(Opaque issuer, orbasec.util.List authorities, 
	                org.omg.CORBA.StringHolder emsg)
	{
		if (authorities.isNil())
			return true;
			
		String errmsg = "Violation of Trusted Authority Policy.";
		try {
			isAuthority isIssuer = new isAuthority(issuer);
			
			// This would be slow if we had a lot of them
			// Should work up a hash table.
			orbasec.SecLev2.TrustedAuthority auth = 
				(orbasec.SecLev2.TrustedAuthority) authorities.lookup(isIssuer); 
			if (auth != null) {
				return true;
			}
			errmsg = "Authority " + issuer + " is not trusted.";
			throw new orbasec.corba.SecurityError(errmsg);
        } catch (Exception e) {
			/* START DEBUG */
			if (Debug.debug) {
				Debug.println(Debug.SECIOP, "   " + e); 
			}
			/* END DEBUG */
			if (emsg != null)
				emsg.value = errmsg;
           return false;
        } catch (Error e) {
			/* START DEBUG */
			if (Debug.debug) {
				Debug.println(Debug.SECIOP, "   " + e); 
			}
			/* END DEBUG */
			if (emsg != null)
				emsg.value = errmsg;
           return false;
        }
    }
		
 	private static final class isAuthority implements Pred1 {
		byte[] issuer;
		isAuthority(Opaque n) {
			issuer = n.getEncoding();
		}
		isAuthority(byte[] n) {
			issuer = n;
		}
		public boolean pred(Object obj)
		{
			orbasec.SecLev2.TrustedAuthority auth = 
				(orbasec.SecLev2.TrustedAuthority) obj;
						// Canonicalize the name just in case.
			try {
				String name =  Opaque.decode(auth.security_name).toString();
				name = canonicalizeKerberosName(name);
				byte[] security_name = Opaque.encodeKerberosName(name)
												.getEncoding();
				return CredUtil.equals(issuer,security_name);
			} catch (Exception e) {
				return false;
			}
		}
	}
	
	static String
	canonicalizeKerberosName(String name)
	{
		int maj_stat;
		gss_int_holder    min_stat    = new gss_int_holder();
		gss_name_t        target_name = new gss_name_t();
		gss_buffer_holder send_tok    = new gss_buffer_holder();
		gss_int_holder    ret_flags   = new gss_int_holder();
		
		maj_stat = gss.import_name(min_stat, name,
		                           gss.gss_nt_user_name, target_name);
		                           
		if (maj_stat != gss.GSS_S_COMPLETE) {
			throw new GSSError( "parsing target name", maj_stat, min_stat.value);
		}

	    //
	    // Get the target name
	    //
	    gss_string_holder tnameh = new gss_string_holder();
	    gss_OID           diod   = new gss_OID();
		maj_stat = gss.display_name(min_stat, target_name, tnameh, diod);
		if (maj_stat != gss.GSS_S_COMPLETE) {
			throw new GSSError("displaying name", maj_stat, min_stat.value);
	    }

		return new String(tnameh.buffer());
	}
	
}
